// ICommandTargetVisitor.cs
//
// Author:
//   Lluis Sanchez Gual <lluis@novell.com>
//
// Copyright (c) 2007 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//
//


using System;

namespace MonoDevelop.Components.Commands
{
	/// <summary>
	/// A visitor for the command route
	/// </summary>
	public interface ICommandTargetVisitor
	{
		/// <summary>
		/// Called when a visit operation is started
		/// </summary>
		void Start ();

		/// <summary>
		/// Called for every object in the hierarchy
		/// </summary>
		/// <param name='ob'>
		/// Visited object
		/// </param>
		/// <returns>
		/// True if the visit operation has to be stopped
		/// </returns>
		bool Visit (object ob);

		/// <summary>
		/// Called when the visit operation ends
		/// </summary>
		void End ();
	}
}
